@@ -304,7 +304,7 @@ void SymfonieMediaPlayer::saveState(){
         SymfonieDb::getInstance()->saveSetting("last_played_position", QVariant(0));
     }
 
-   SymfonieDb::getInstance()->saveSetting("is_equalizer_enabled", QVariant(this->isEqualizerEnabled == true ? 1: 0));
+    SymfonieDb::getInstance()->saveSetting("is_equalizer_enabled", QVariant(this->isEqualizerEnabled == true ? 1: 0));
 }
 
 
@@ -337,108 +337,29 @@ void SymfonieMediaPlayer::setFileFilter(QStringList filterList){
     this->fileFilterList = filterList;
 }
 
-
-SymfoniePlayList* SymfonieMediaPlayer::scanDirRecursive(QString path){
-    SymfoniePlayList *playList = new SymfoniePlayList(path);
-    this->addInitialDir(playList, path);
-    this->scanDirRecursiveBase(playList, path);
-    this->doScanDirCompleted(playList, path);
-    return playList;
-}
-
-void SymfonieMediaPlayer::scanDirRecursiveBase(SymfoniePlayList *playList, QString path){
-    qDebug() << "Visit directory " << path;
-    QStringList dirList = this->getDirectoryListByPath(path);
-
-    for (int i = 0; i < dirList.size(); i++) {
-        QFileInfo dirInfo(path + "/" +dirList.at(i));
-        QString dirPath = dirInfo.canonicalFilePath();
-
-         qDebug() << dirList.at(i) << dirInfo.isDir();
-
-        if(!dirInfo.isDir()){
-            continue;
-        }
-
-        qDebug() << path << dirPath << dirList.at(i);
-        if(QString::compare(path, dirPath) == 0){
-
-            continue;
-        }
-
-        this->scanDirRecursiveBase(playList, dirPath);
-
-    }
-
-
-    QStringList fileList = this->getFileListByPath(path);
-
-    for (int i = 0; i < fileList.size(); i++) {
-        QFileInfo fileInfo(path + "/" +fileList.at(i));
-        QString filePath = fileInfo.canonicalFilePath();
-
-        SymfoniePlayListItemFile *file =  new SymfoniePlayListItemFile(filePath);
-        file->setDisplayName(fileInfo.fileName());
-        playList->addFile(file);
-    }
-
-}
-
-QStringList SymfonieMediaPlayer::getDirectoryListByPath(QString path){
-    QDir directory(path);
-
-    QStringList dirList = directory.entryList(
-            QStringList(),
-            QDir::Dirs|QDir::NoDotAndDotDot|QDir::Drives|QDir::AllDirs
-            );
-
-    return dirList;
-}
-
-QStringList SymfonieMediaPlayer::getFileListByPath(QString path){
-    QDir directory(path);
-    QStringList fileList = directory.entryList(this->fileFilterList);
-    return fileList;
-}
-
-
-void SymfonieMediaPlayer::addInitialDir(SymfoniePlayList *playList, QString path){
-    QFileInfo fileInfo(path + "/..");
-    SymfoniePlayListItemFolder *folder =  new SymfoniePlayListItemFolder(path, SymfoniePlayListItem::DotDot);
-    folder->setDisplayName(path);
-    folder->setName(fileInfo.canonicalFilePath());
-    playList->addFolder(folder);
-}
-
 //remove any entry in the list
-SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){
+SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){//bool isUpdatePlayList){
 
-   // QDir directory(path);
+    QDir directory(path);
 
     SymfoniePlayList *playList = new SymfoniePlayList(path);
 
-    //QStringList fileList = directory.entryList(this->fileFilterList);
-    /*
+    QStringList fileList = directory.entryList(this->fileFilterList);
     QStringList dirList = directory.entryList(
             QStringList(),
             QDir::Dirs|QDir::NoDotAndDotDot|QDir::Drives|QDir::AllDirs
             );
 
-*/
-    // playList->clear();
-    QStringList fileList = this->getFileListByPath(path);
-    QStringList dirList = this->getDirectoryListByPath(path);
 
-/*
+    // playList->clear();
+
     SymfoniePlayListItemFolder *folder =  new SymfoniePlayListItemFolder(path, SymfoniePlayListItem::DotDot);
     QFileInfo fileInfo(path + "/..");
     folder->setDisplayName(path);
     folder->setName(fileInfo.canonicalFilePath());
     playList->addFolder(folder);
- */
-    this->addInitialDir(playList, path);
 
-   // qDebug() << "first dir = "  << folder->getName() << " | " << path + "/.." << " can name: " + fileInfo.canonicalFilePath();
+    qDebug() << "first dir = "  << folder->getName() << " | " << path + "/.." << " can name: " + fileInfo.canonicalFilePath();
 
     for (int i = 0; i < dirList.size(); i++) {
         QFileInfo fileInfo(path + "/" +dirList.at(i));
@@ -462,7 +383,6 @@ SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){
 
             SymfoniePlayListItemFile *file =  new SymfoniePlayListItemFile(filePath);
             file->setDisplayName(fileInfo.fileName());
-            playList->addFile(file);
 
             /*
         SymfonieSong *song = SymfonieSong::findByFilePath(filePath);
@@ -481,7 +401,7 @@ SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){
         file->setSong(song);
 */
 
-
+            playList->addFile(file);
         }
     }
 
@@ -496,13 +416,9 @@ SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){
     }
     */
 
-
-    this->doScanDirCompleted(playList, path);
-    return playList;
-}
-
-void SymfonieMediaPlayer::doScanDirCompleted(SymfoniePlayList *playList, QString path){
     emit scanDirCompletedSignal(playList, path);
+
+    return playList;
 }
 
 SymfoniePlayList *SymfonieMediaPlayer::getPlayList(){
@@ -651,10 +567,6 @@ void SymfonieMediaPlayer::enqueue(int index){
     this->queuedIndex = index;
 }
 
-void SymfonieMediaPlayer::stop(){
-    this->player->stop();
-}
-
 void SymfonieMediaPlayer::playPrevious(){
     this->enqueue(this->getPreviousPlaybackIndex());
     this->play();
@@ -683,22 +595,20 @@ void SymfonieMediaPlayer::setIsContinuouslyPlay(bool flag){
 }
 
 bool SymfonieMediaPlayer::getIsContinuouslyPlay(){
-    return this->isContinuouslyPlay;
+    this->isContinuouslyPlay;
 }
 
 void SymfonieMediaPlayer::aboutToFinishSlot(){
-    if(!this->getIsContinuouslyPlay() && this->getPlayList()->isIndexLast(this->getCurrentPlaybackIndex())){
-        this->player->stop();
-    }else{
+    if(this->getIsContinuouslyPlay() && this->getPlayList()->isIndexLast(this->getCurrentPlaybackIndex())){
+        return;
+    }
+
     this->queuedIndex = this->getNextPlaybackIndex();
 
+
     this->player->clearQueue();
     this->player->enqueue(Phonon::MediaSource(this->getFilePathAt(this->queuedIndex)));
 }
-    qDebug() << "IS con:" << this->getIsContinuouslyPlay()
-            << "Is last: "<< this->getPlayList()->isIndexLast(this->getCurrentPlaybackIndex())
-            << "current index: " << this->getCurrentPlaybackIndex();
-}
 
 
 void SymfonieMediaPlayer::currentSourceChangedSlot ( const Phonon::MediaSource &/*newSource*/ ) {
@@ -706,27 +616,3 @@ void SymfonieMediaPlayer::currentSourceChangedSlot ( const Phonon::MediaSource &
 }
 
 
-void SymfonieMediaPlayer::enableShuffle(){
-    this->getPlayList()->enableShuffle();
-}
-
-void SymfonieMediaPlayer::disableShuffle(){
-    this->getPlayList()->disableShuffle();
-}
-
-bool SymfonieMediaPlayer::getIsShuffleEnabled(){
-    return this->getPlayList()->getIsShuffleEnabled();
-}
-
-
-void SymfonieMediaPlayer::enableRepeat(){
-    this->getPlayList()->enableRepeat();
-}
-
-void SymfonieMediaPlayer::disableRepeat(){
-    this->getPlayList()->disableRepeat();
-}
-
-bool SymfonieMediaPlayer::getIsRepeatEnabled(){
-    return this->getPlayList()->getIsRepeatEnabled();
-}
